@@ -1,29 +1,17 @@
 package Class::Scaffold::Introspect;
-
 use warnings;
 use strict;
 use FindBin '$Bin';
 use Cwd;
 use File::Spec::Functions qw/curdir updir rootdir rel2abs/;
 use Sys::Hostname;
-
-
-our $VERSION = '0.15';
-
-
-use base 'Exporter';
-
-
-our %EXPORT_TAGS = (
-    conf => [ qw/find_conf_file/ ],
-);
-
+our $VERSION = '0.16';
+use Exporter qw(import);
+our %EXPORT_TAGS = (conf => [qw/find_conf_file/],);
 our @EXPORT_OK = @{ $EXPORT_TAGS{all} = [ map { @$_ } values %EXPORT_TAGS ] };
 
-
 sub find_file_upwards {
-    my $wanted_file = shift;
-
+    my $wanted_file  = shift;
     my $previous_cwd = getcwd;
     my $result;    # left undef as we'll return undef if we didn't find it
     while (rel2abs(curdir()) ne rootdir()) {
@@ -37,7 +25,6 @@ sub find_file_upwards {
     $result;
 }
 
-
 sub find_conf_file {
     my $file = 'SMOKEconf.yaml';
 
@@ -48,22 +35,18 @@ sub find_conf_file {
     # perl t/sometest.t
     # cd t; perl sometest.t
     # perl /abs/path/to/distro/t/sometest.t
-
     chdir($Bin) or die "can't chdir to [$Bin]: $!\n";
     my $distro_root = find_file_upwards('Makefile.PL');
-
     unless (defined $distro_root && length $distro_root) {
         warn "can't find distro root from [$Bin]\n";
         warn "might not be able to find conf file using [$ENV{CF_CONF}]\n"
-            if $ENV{CF_CONF} eq 'local';
+          if $ENV{CF_CONF} eq 'local';
         return;
     }
-
     my $etc = "$distro_root/etc";
     return "$etc/$file" if -e "$etc/$file";
 
     # warn "find_conf_file: not in [$etc/$file]";
-
     (my $hostname = hostname) =~ s/\W.*//;
     my $dir = "$etc/$hostname";
     return "$dir/$file" if -d $dir && -e "$dir/$file";
@@ -71,15 +54,9 @@ sub find_conf_file {
     # warn "find_conf_file: not in [$dir/$file]";
     undef;
 }
-
-
 1;
-
-
 __END__
 
-
-
 =head1 NAME
 
 Class::Scaffold::Introspect - large-scale OOP application support
@@ -94,17 +71,8 @@ Class::Scaffold::Introspect - large-scale OOP application support
 
 =over 4
 
-
-
 =back
 
-Class::Scaffold::Introspect inherits from L<Exporter>.
-
-The superclass L<Exporter> defines these methods and functions:
-
-    as_heavy(), export(), export_fail(), export_ok_tags(), export_tags(),
-    export_to_level(), import(), require_version()
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
@@ -141,6 +109,5 @@ Copyright 2004-2009 by the authors.
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-
 =cut
 
